import React, { Children } from "react";
import classNames from "classnames";

/* -------------------------------------------------------------------------- */
/*                                 Components                                 */
/* -------------------------------------------------------------------------- */
import Typography from "./typography/Typography";
import Heading from "./typography/Heading";
import Link from "./Link";

/* -------------------------------------------------------------------------- */
/*                                    Props                                   */
/* -------------------------------------------------------------------------- */
type Props = {
  /**
   * Card component accept children
   */
  children: React.ReactNode;
  /**
   * Styling the card component
   */
  className?: string | undefined;
};

const Card = ({ children, className }: Props) => {
  return (
    <div
      className={classNames([
        className,
        "inline-flex flex-col justify-between p-4 max-w-xs lg:max-w-sm h-52 items-start rounded border border-[#F0F0F0]  gap-y-8 overflow-hidden",
      ])}
    >
      {children}
    </div>
  );
};

// Avatar props and function
type AvatarProps = {
  children?: React.ReactNode;
};
Card.Avatar = function CardAvatar({ children }: AvatarProps) {
  return <>{children}</>;
};
// The end of Body props and function

// Title props and function
Card.Title = function CardTitle({ children, className }: Props) {
  return (
    <Heading className={classNames([className, "select-none leading-7"])}>
      {children}
    </Heading>
  );
};
// The end Title props and function

// Body props and function
Card.Body = function CardTitle({ children, className }: Props) {
  return (
    <Typography
      fontWeightVariant="normal"
      className={classNames([className, "text-sm"])}
    >
      {children}
    </Typography>
  );
};
// The end of Body props and function

// Cardheader props and function
Card.Cardheader = function CardCardheader({ children, className }: Props) {
  return (
    <div className={classNames([className, "first flex items-start gap-4"])}>
      {children}
    </div>
  );
};
// The end of Cardheader props and function

// Cardcontent props and function
Card.Cardcontent = function CardCardcontent({ children, className }: Props) {
  return (
    <div className={classNames([className, "flex flex-col gap-y-4"])}>
      {children}
    </div>
  );
};
// The end of Cardcontent props and function

// Cardaction props and function
type CardactionProps = {
  children: React.ReactNode;
  className?: string | undefined;
  href?: string;
};
Card.Cardaction = function CardCardaction({
  children,
  className,
  href = "#",
}: CardactionProps) {
  return (
    <Link
      href={href}
      className={classNames([className, "flex items-center gap-2"])}
    >
      {children}
    </Link>
  );
};
// The end of Cardaction props and function

export default Card;
